/*
 * annex.h
 * 
 * Forked from https://git.devuan.org/kryn/hopman/src/branch/master/hopman-1.1/annex/annex.h
 *  - Copyright (C) 2019 Didier Kryn <kryn@in2p3.fr>
 * 
 * All modifications to the original source file are:
 *  - Copyright (C) 2022 Aitor Cuadrado Zubizarreta <aitor_czr@gnuinos.org> 
 *
 * This program is free software: you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the
 * Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program.  If not, see <http://www.gnu.org/licenses/>.
 * 
 * See the LISENCE file.
 */

#if !defined(ANNEX_H)
#define ANNEX_H
#include <sys/types.h>

#define strdup_or_null( str )  (str) != NULL ? strdup(str) : NULL

typedef
enum {Directory, Application, Separator} type_t;

/*--------------- Interface with the configuration file --------------------*/
/* parameters:,  IDs, names and default values: */
typedef enum paramid_t
  {
    ApplicationLauncher, TerminalEmulator, FileManager, TextEditor, WebBrowser, 
    Logout, N_CONFIG_PARAMS
  } paramid_t;

#define PARAM_NAMES "applicationlauncher", "terminalemulator", "filemanager", \
	"texteditor", "webbrowser", "logout"

#define PARAM_DEFAULTS "gmrun", "sakura", "spacefm" , "geany", "icecat", "logout"

int userinfo_init(void);
void do_all_config(void);
const char *username(void);
const char *userhome(void);
int config_read(const char *path);
const char *config_pidfile(char *wbuf, size_t len);
const char *config_string(paramid_t param);
int config_bool(paramid_t param);
int config_int(paramid_t param);
void newpid(void);

typedef struct node_t {
	
	type_t type;
	int numItems;
	char name[64];
	char exec[64];
	char icon[128];
	char category[64];
  
} node_t;

struct nodeList {
	
	node_t nodeT;
	struct nodeList *next;
};

struct nodeList *add_new_node(struct nodeList *, node_t);
struct nodeList *insert_new_node(struct nodeList*, node_t, int (*f)(node_t, node_t));
struct nodeList *append_new_node(struct nodeList*, node_t);
struct nodeList *clear_list(struct nodeList*);

void rsvg_convert(const char*, const char*);

/*
  The configuration data is shared between userinfo.c and config.c .
  The same buffer is allocated and re-allocated. The two functions are
  reallocation-safe: userinfo.c by keeping the offsets of its two strings,
  instead of pointers, and config.c by keeping track of the value of
  configbuf and updating its pointers in case of change. Therefore the
  calling order of the two functions only matters because userinfo is
  needed to determine the path of the configuration file. This is how it
  has been designed, but no wild reallocation of configbuf has been tried
  to check the safety of the two functions.
*/
# ifdef DECLARE_CONFIGBUF
char *configbuf;
size_t configlen;
# else
extern char *configbuf;
extern size_t configlen;
# endif
#endif
